package com.sun.xml.internal.bind.v2.schemagen;

import com.sun.xml.internal.txw2.TypedXmlWriter;
import com.sun.xml.internal.bind.v2.schemagen.xmlschema.LocalAttribute;
import javax.xml.namespace.QName;
import com.sun.xml.internal.bind.v2.schemagen.xmlschema.LocalElement;
import com.sun.xml.internal.bind.v2.schemagen.xmlschema.Schema;
import javax.xml.bind.annotation.XmlNsForm;

enum Form
{
    QUALIFIED(XmlNsForm.QUALIFIED, true) {
        @Override
        void declare(String attName, Schema schema) {
            schema._attribute(attName, "qualified");
        }
    }, 
    UNQUALIFIED(XmlNsForm.UNQUALIFIED, false) {
        @Override
        void declare(String attName, Schema schema) {
            schema._attribute(attName, "unqualified");
        }
    }, 
    UNSET(XmlNsForm.UNSET, false) {
        @Override
        void declare(String attName, Schema schema) {
        }
    };
    
    private final XmlNsForm xnf;
    public final boolean isEffectivelyQualified;
    
    private Form(XmlNsForm xnf, boolean effectivelyQualified) {
        this.xnf = xnf;
        this.isEffectivelyQualified = effectivelyQualified;
    }
    
    abstract void declare(String p0, Schema p1);
    
    public void writeForm(LocalElement e, QName tagName) {
        this._writeForm(e, tagName);
    }
    
    public void writeForm(LocalAttribute a, QName tagName) {
        this._writeForm(a, tagName);
    }
    
    private void _writeForm(TypedXmlWriter e, QName tagName) {
        boolean qualified = tagName.getNamespaceURI().length() > 0;
        if (qualified && this != Form.QUALIFIED) {
            e._attribute("form", "qualified");
        }
        else if (!qualified && this == Form.QUALIFIED) {
            e._attribute("form", "unqualified");
        }
    }
    
    public static Form get(XmlNsForm xnf) {
        Form[] values = values();
        int length = values.length;
        int i = 0;
        while (i < length) {
            Form v = values[i];
            if (v.xnf == xnf) {
                return v;
            }
            ++i;
        }
        throw new IllegalArgumentException();
    }
    
    Form(String x0, int x1, XmlNsForm x2, boolean x3, Form.1 x4) {
        this(x2, x3);
    }
}
